/************************************************************************************
 *
 *   file name   : func_uart_tr.c
 *   Contents    : asynchronous serial I/O communication (transmit)
 *
 *   Copyright, 2004 RENESAS TECHNOLOGY CORPORATION
 *                   AND RENESAS SOLUTIONS CORPORATION
 *
 *   Version     : 1.00  ( 2004-10-30 )
 *
*************************************************************************************/
/************************************************************************************
 *
 *      include
 *
*************************************************************************************/
#include <stdio.h>
#include <intr740.h>
#include "io7544.h"

/************************************************************************************
 *
 *      definition
 *
*************************************************************************************/
bit ICON2_bit5 = ICON2.5;
bit IREQ2_bit5 = IREQ2.5;
bit SIOSTS_bit0 = SIOSTS.0;
bit SIOSTS_bit2 = SIOSTS.2;

/*==================================================================================*/

/************************************************************************************
 *
 *      main
 *
*************************************************************************************/
void main(void)
{
		char SEND_DATA1;
		char SEND_DATA2;

		/***   wait 10ms(f(Ring))   ***/
		disable_interrupt();					/* Interrupt disable */
		CPUM		= 0x80;
		ICON2_bit5	= 0;
		IREQ2_bit5	= 0;
		TCSS2		= 0x02;
		PRE1		= 200-1;
		T1			= 100-1;
		IREQ2_bit5	= 0;
		nop_instruction();
		
		while(IREQ2_bit5 == 0){}
		
		CPUM = 0x00;
		
		/***   main program   ***/
		SIOCON		= 0x91;						/* BRG count source : f(Xin)/4 */
												/* synchronous clock : divided 16 */
												/* interrupt request factor : transmit buffer is empty */
												/* enable transmit */
												/* disable receive */
												/* serial I/O mode : asynchronous serial I/O mode */
												/* enable serial I/O */
		UARTCON		= 0x08;						/* character length bit : 8 bits */
												/* disable parity */
												/* 2 stop bits */
												/* TxD : CMOS output */
		BRG			= 0x07;						/* set baud rate */
		
		P0			= 0x00;
		P0D			= 0x01;						/* set port P0 direction register */

		SEND_DATA1	= 0x55;						/* set send data */
		SEND_DATA2	= 0xAA;

		TCSS2		= 0x01;						/* select timer 1 count source */
		PRE1		= 0xF9;						/* transmit cycle 10ms */
		T1			= 0x61;

		IREQ2_bit5	= 0;						/* clear timer 1 interrupt request */
		nop_instruction();
		
		while(1){
			while(IREQ2_bit5 == 0);				/* 10ms ? */
			IREQ2_bit5 = 0;						/* clear timer 1 interrupt request */
			
			P0_0 = 1;							/* transmit start flag */
			
			TBRB = SEND_DATA1;					/* write trasmit data */
			
			while(SIOSTS_bit0 == 0);			/* wait data send */

			TBRB = SEND_DATA2;					/* write next transmit data */

			while(SIOSTS_bit0 == 0);			/* wait data send */
			while(SIOSTS_bit2 == 0);			/* wait transmit sift completed */
			
			P0_0 = 0;
		}
}

/************************************************************************************/
