/************************************************************************************
 *
 *   file name   : func_timer4.c
 *   Contents    : Timer A (H and L pulse width continuous measurement mode)
 *
 *   Copyright, 2004 RENESAS TECHNOLOGY CORPORATION
 *                   AND RENESAS SOLUTIONS CORPORATION
 *
 *   Version     : 1.00  ( 2004-10-30 )
 *
*************************************************************************************/
/************************************************************************************
 *
 *      include
 *
*************************************************************************************/
#include <stdio.h>
#include <intr740.h>
#include "io7544.h"

/************************************************************************************
 *
 *      definition
 *
*************************************************************************************/
bit ICON2_bit5 = ICON2.5;
bit IREQ2_bit5 = IREQ2.5;
bit ICON2_bit2 = ICON2.2;
bit ICON1_bit6 = ICON1.6;
bit P0D_0 = P0D.0;
bit PULL_bit0 = PULL.0;
bit INTEDGE_bit7 = INTEDGE.7;
bit IREQ2_bit2 = IREQ2.2;
bit IREQ1_bit6 = IREQ1.6;
bit TAM_bit7 = TAM.7;

/*==================================================================================*/
zpage	char TimerA_CNT;
zpage	char B_TimerA_CNT;
zpage	char B_TimerA_CNT_L;
zpage	char B_TimerA_CNT_H;
zpage	char RING_CNT;
zpage	char fix_H;
zpage	char fix_L;
zpage	char f_RING;
zpage	char f_error;
zpage	char f_first_edge;

void Error_Process(void);

/************************************************************************************
 *
 *      main
 *
*************************************************************************************/
void main(void)
{
		/***   wait 10ms(f(Ring))   ***/
		disable_interrupt();					/* Interrupt disable */
		CPUM		= 0x80;
		ICON2_bit5	= 0;
		IREQ2_bit5	= 0;
		TCSS2		= 0x02;
		PRE1		= 200-1;
		T1			= 100-1;
		IREQ2_bit5	= 0;
		nop_instruction();
		
		while(IREQ2_bit5 == 0){}
		
		CPUM = 0x00;
		
		/***   main program   ***/
		ICON2_bit2		= 0;					/* disable timer A interrupt */
		ICON1_bit6		= 0;					/* disable CNTR1 interrupt */
		
		P0D				= 0x00;
		PULL_bit0		= 0;					/* set P0_0 input mode */
		
		TAM				= 0xB0;					/* H and L pulse width continuous measurement mode */
												/* stop timer A count */

		TCSS2			= 0x00;					/* select timer A count source : f(XIN)/16 */
		
		TAL				= 0x1F;					/* set timer A low-order */
		TAH				= 0x4E;					/* set timer A high-order */
		
		INTEDGE_bit7	= 1;					/* disable key on wake-up interrupt */
		
		IREQ2_bit2		= 0;					/* clear timer A interrupt request */
		IREQ1_bit6		= 0;					/* clear CNTR1 interrupt request */
		ICON2_bit2		= 1;					/* enable timer A interrupt */
		ICON1_bit6		= 1;					/* enable CNTR1 interrupt */

		f_first_edge	= 1;					/* ignore first edge */

		TAM_bit7		= 0;					/* start timer A count */

		enable_interrupt();						/* Interrupt enable */

		while(1){
			if(f_RING == 1){					/* input ring signal ? */

				/* write processing */

			}
		}

}

/************************************************************************************
 *
 *      interrupt CNTR1
 *
*************************************************************************************/
void interrupt[18] int_CNTR1(void)
{
	cld_instruction();

	if(f_first_edge != 1){
		if(P0_0 == 0){
			if(TimerA_CNT >= 4 && TimerA_CNT < 23){
				fix_H = 1;
				B_TimerA_CNT_L = TimerA_CNT;
			}
			else{
				Error_Process();
				return;
			}
		}
		else{
			if(TimerA_CNT >= 12 && TimerA_CNT < 43){
				fix_L = 1;
				B_TimerA_CNT_H = TimerA_CNT;
			}
			else{
				Error_Process();
				return;
			}
		}

		if(fix_H == 1 && fix_L == 1){
			B_TimerA_CNT = B_TimerA_CNT_L + B_TimerA_CNT_H;
			if(B_TimerA_CNT >= 20 && B_TimerA_CNT < 59){
				fix_L = fix_H  = 0;
				RING_CNT ++;
				if(RING_CNT > 5){
					f_RING = 1;
					RING_CNT = 0;
				}
			}
			else{
				Error_Process();
				return;
			}
		}
	}
	else{
		f_first_edge = 0;
	}

	TimerA_CNT = 0;

}

/************************************************************************************
 *
 *      sub-routine error processing
 *
*************************************************************************************/
void Error_Process(void){
		fix_H = 0;
		fix_L = 0;
		RING_CNT = 0;
		f_error = 1;
		TimerA_CNT = 0;
	
}

/************************************************************************************
 *
 *      interrupt Timer A
 *
*************************************************************************************/
void interrupt[10] int_TA(void)
{
		cld_instruction();

		TimerA_CNT ++;

}

/************************************************************************************/
